# automatically generated file. DO NOT CHANGE MANUALLY

from __future__ import annotations

from typing import Any, Dict, List, Optional

from pydantic import BaseModel, Field

import pdk8s.model

from ..... import Kind171, Kind172, Kind173, Kind174, Kind175, Kind176, Kind177, Kind178
from ...apimachinery.pkg.apis.meta import v1 as v1_1
from ..core import v1


class CSIDriverSpec(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    attach_required: Optional[bool] = Field(
        None,
        alias="attachRequired",
        description="attachRequired indicates this CSI volume driver requires an attach operation (because it implements the CSI ControllerPublishVolume() method), and that the Kubernetes attach detach controller should call the attach volume interface which checks the volumeattachment status and waits until the volume is attached before proceeding to mounting. The CSI external-attacher coordinates with CSI volume driver and updates the volumeattachment status when the attach operation is complete. If the CSIDriverRegistry feature gate is enabled and the value is specified to false, the attach operation will be skipped. Otherwise the attach operation will be called.",
    )
    pod_info_on_mount: Optional[bool] = Field(
        None,
        alias="podInfoOnMount",
        description='If set to true, podInfoOnMount indicates this CSI volume driver requires additional pod information (like podName, podUID, etc.) during mount operations. If set to false, pod information will not be passed on mount. Default is false. The CSI driver specifies podInfoOnMount as part of driver deployment. If true, Kubelet will pass pod information as VolumeContext in the CSI NodePublishVolume() calls. The CSI driver is responsible for parsing and validating the information passed in as VolumeContext. The following VolumeConext will be passed if podInfoOnMount is set to true. This list might grow, but the prefix will be used. "csi.storage.k8s.io/pod.name": pod.Name "csi.storage.k8s.io/pod.namespace": pod.Namespace "csi.storage.k8s.io/pod.uid": string(pod.UID) "csi.storage.k8s.io/ephemeral": "true" iff the volume is an ephemeral inline volume\n                                defined by a CSIVolumeSource, otherwise "false"\n\n"csi.storage.k8s.io/ephemeral" is a new feature in Kubernetes 1.16. It is only required for drivers which support both the "Persistent" and "Ephemeral" VolumeLifecycleMode. Other drivers can leave pod info disabled and/or ignore this field. As Kubernetes 1.15 doesn\'t support this field, drivers can only support one mode when deployed on such a cluster and the deployment determines which mode that is, for example via a command line parameter of the driver.',
    )
    volume_lifecycle_modes: Optional[List[str]] = Field(
        None,
        alias="volumeLifecycleModes",
        description='VolumeLifecycleModes defines what kind of volumes this CSI volume driver supports. The default if the list is empty is "Persistent", which is the usage defined by the CSI specification and implemented in Kubernetes via the usual PV/PVC mechanism. The other mode is "Ephemeral". In this mode, volumes are defined inline inside the pod spec with CSIVolumeSource and their lifecycle is tied to the lifecycle of that pod. A driver has to be aware of this because it is only going to get a NodePublishVolume call for such a volume. For more information about implementing this mode, see https://kubernetes-csi.github.io/docs/ephemeral-local-volumes.html A driver can support one or more of these modes and more modes may be added in the future.',
    )


class VolumeNodeResources(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    count: Optional[int] = Field(
        None,
        description="Maximum number of unique volumes managed by the CSI driver that can be used on a node. A volume that is both attached and mounted on a node is considered to be used once, not twice. The same rule applies for a unique volume that is shared among multiple pods on the same node. If this field is nil, then the supported number of volumes on this node is unbounded.",
    )


class CSINodeDriver(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    allocatable: Optional[VolumeNodeResources] = Field(
        None,
        description="allocatable represents the volume resources of a node that are available for scheduling.",
    )
    name: str = Field(
        ...,
        description="This is the name of the CSI driver that this object refers to. This MUST be the same name returned by the CSI GetPluginName() call for that driver.",
    )
    node_id: str = Field(
        ...,
        alias="nodeID",
        description='nodeID of the node from the driver point of view. This field enables Kubernetes to communicate with storage systems that do not share the same nomenclature for nodes. For example, Kubernetes may refer to a given node as "node1", but the storage system may refer to the same node as "nodeA". When Kubernetes issues a command to the storage system to attach a volume to a specific node, it can use this field to refer to the node name using the ID that the storage system will understand, e.g. "nodeA" instead of "node1". This field is required.',
    )
    topology_keys: Optional[List[str]] = Field(
        None,
        alias="topologyKeys",
        description='topologyKeys is the list of keys supported by the driver. When a driver is initialized on a cluster, it provides a set of topology keys that it understands (e.g. "company.com/zone", "company.com/region"). When a driver is initialized on a node, it provides the same topology keys along with values. Kubelet will expose these topology keys as labels on its own node object. When Kubernetes does topology aware provisioning, it can use this list to determine which labels it should retrieve from the node object and pass back to the driver. It is possible for different nodes to use different topology keys. This can be empty if driver does not support topology.',
    )


class CSINodeSpec(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    drivers: List[CSINodeDriver] = Field(
        ...,
        description="drivers is a list of information of all CSI Drivers existing on a node. If all drivers in the list are uninstalled, this can become empty.",
    )


class VolumeError(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    message: Optional[str] = Field(
        None,
        description="String detailing the error encountered during Attach or Detach operation. This string may be logged, so it should not contain sensitive information.",
    )
    time: Optional[v1.Time] = Field(None, description="Time the error was encountered.")


class CSIDriver(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    kind: Optional[Kind171] = Field(
        "CSIDriver",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ObjectMeta] = Field(
        None,
        description="Standard object metadata. metadata.Name indicates the name of the CSI driver that this object refers to; it MUST be the same name returned by the CSI GetPluginName() call for that driver. The driver name must be 63 characters or less, beginning and ending with an alphanumeric character ([a-z0-9A-Z]) with dashes (-), dots (.), and alphanumerics between. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )
    spec: CSIDriverSpec = Field(..., description="Specification of the CSI Driver.")


class CSIDriverList(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    items: List[CSIDriver] = Field(..., description="items is the list of CSIDriver")
    kind: Optional[Kind172] = Field(
        "CSIDriverList",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ListMeta] = Field(
        None,
        description="Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )


class CSINode(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    kind: Optional[Kind173] = Field(
        "CSINode",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ObjectMeta] = Field(
        None, description="metadata.name must be the Kubernetes node name."
    )
    spec: CSINodeSpec = Field(..., description="spec is the specification of CSINode")


class CSINodeList(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    items: List[CSINode] = Field(..., description="items is the list of CSINode")
    kind: Optional[Kind174] = Field(
        "CSINodeList",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ListMeta] = Field(
        None,
        description="Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )


class StorageClass(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    allow_volume_expansion: Optional[bool] = Field(
        None,
        alias="allowVolumeExpansion",
        description="AllowVolumeExpansion shows whether the storage class allow volume expand",
    )
    allowed_topologies: Optional[List[v1.TopologySelectorTerm]] = Field(
        None,
        alias="allowedTopologies",
        description="Restrict the node topologies where volumes can be dynamically provisioned. Each volume plugin defines its own supported topology specifications. An empty TopologySelectorTerm list means there is no topology restriction. This field is only honored by servers that enable the VolumeScheduling feature.",
    )
    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    kind: Optional[Kind175] = Field(
        "StorageClass",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1_1.ObjectMeta] = Field(
        None,
        description="Standard object's metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )
    mount_options: Optional[List[str]] = Field(
        None,
        alias="mountOptions",
        description='Dynamically provisioned PersistentVolumes of this storage class are created with these mountOptions, e.g. ["ro", "soft"]. Not validated - mount of the PVs will simply fail if one is invalid.',
    )
    parameters: Optional[Dict[str, Any]] = Field(
        None,
        description="Parameters holds the parameters for the provisioner that should create volumes of this storage class.",
    )
    provisioner: str = Field(
        ..., description="Provisioner indicates the type of the provisioner."
    )
    reclaim_policy: Optional[str] = Field(
        None,
        alias="reclaimPolicy",
        description="Dynamically provisioned PersistentVolumes of this storage class are created with this reclaimPolicy. Defaults to Delete.",
    )
    volume_binding_mode: Optional[str] = Field(
        None,
        alias="volumeBindingMode",
        description="VolumeBindingMode indicates how PersistentVolumeClaims should be provisioned and bound.  When unset, VolumeBindingImmediate is used. This field is only honored by servers that enable the VolumeScheduling feature.",
    )


class StorageClassList(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    items: List[StorageClass] = Field(
        ..., description="Items is the list of StorageClasses"
    )
    kind: Optional[Kind176] = Field(
        "StorageClassList",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ListMeta] = Field(
        None,
        description="Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )


class VolumeAttachmentSource(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    inline_volume_spec: Optional[v1.PersistentVolumeSpec] = Field(
        None,
        alias="inlineVolumeSpec",
        description="inlineVolumeSpec contains all the information necessary to attach a persistent volume defined by a pod's inline VolumeSource. This field is populated only for the CSIMigration feature. It contains translated fields from a pod's inline VolumeSource to a PersistentVolumeSpec. This field is alpha-level and is only honored by servers that enabled the CSIMigration feature.",
    )
    persistent_volume_name: Optional[str] = Field(
        None,
        alias="persistentVolumeName",
        description="Name of the persistent volume to attach.",
    )


class VolumeAttachmentSpec(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    attacher: str = Field(
        ...,
        description="Attacher indicates the name of the volume driver that MUST handle this request. This is the name returned by GetPluginName().",
    )
    node_name: str = Field(
        ...,
        alias="nodeName",
        description="The node that the volume should be attached to.",
    )
    source: VolumeAttachmentSource = Field(
        ..., description="Source represents the volume that should be attached."
    )


class VolumeAttachmentStatus(BaseModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "forbid"

    attach_error: Optional[VolumeError] = Field(
        None,
        alias="attachError",
        description="The last error encountered during attach operation, if any. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.",
    )
    attached: bool = Field(
        ...,
        description="Indicates the volume is successfully attached. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.",
    )
    attachment_metadata: Optional[Dict[str, Any]] = Field(
        None,
        alias="attachmentMetadata",
        description="Upon successful attach, this field is populated with any information returned by the attach operation that must be passed into subsequent WaitForAttach or Mount calls. This field must only be set by the entity completing the attach operation, i.e. the external-attacher.",
    )
    detach_error: Optional[VolumeError] = Field(
        None,
        alias="detachError",
        description="The last error encountered during detach operation, if any. This field must only be set by the entity completing the detach operation, i.e. the external-attacher.",
    )


class VolumeAttachment(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    kind: Optional[Kind177] = Field(
        "VolumeAttachment",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ObjectMeta] = Field(
        None,
        description="Standard object metadata. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )
    spec: VolumeAttachmentSpec = Field(
        ...,
        description="Specification of the desired attach/detach volume behavior. Populated by the Kubernetes system.",
    )


class VolumeAttachmentList(pdk8s.model.NamedModel):
    class Config:
        allow_population_by_field_name = True
        validate_assignment = True
        extra = "allow"

    api_version: Optional[str] = Field(
        "storage.k8s.io/v1beta1",
        alias="apiVersion",
        description="APIVersion defines the versioned schema of this representation of an object. Servers should convert recognized schemas to the latest internal value, and may reject unrecognized values. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#resources",
    )
    items: List[VolumeAttachment] = Field(
        ..., description="Items is the list of VolumeAttachments"
    )
    kind: Optional[Kind178] = Field(
        "VolumeAttachmentList",
        description="Kind is a string value representing the REST resource this object represents. Servers may infer this from the endpoint the client submits requests to. Cannot be updated. In CamelCase. More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#types-kinds",
    )
    metadata: Optional[v1.ListMeta] = Field(
        None,
        description="Standard list metadata More info: https://git.k8s.io/community/contributors/devel/sig-architecture/api-conventions.md#metadata",
    )



# automatically generated file. DO NOT CHANGE MANUALLY

from __future__ import annotations

from enum import Enum
from typing import Any

from pydantic import BaseModel


class Model(BaseModel):
    __root__: Any


class Kind(Enum):
    mutating_webhook_configuration = "MutatingWebhookConfiguration"


class Kind1(Enum):
    mutating_webhook_configuration_list = "MutatingWebhookConfigurationList"


class Kind2(Enum):
    validating_webhook_configuration = "ValidatingWebhookConfiguration"


class Kind3(Enum):
    validating_webhook_configuration_list = "ValidatingWebhookConfigurationList"


class Kind4(Enum):
    mutating_webhook_configuration = "MutatingWebhookConfiguration"


class Kind5(Enum):
    mutating_webhook_configuration_list = "MutatingWebhookConfigurationList"


class Kind6(Enum):
    validating_webhook_configuration = "ValidatingWebhookConfiguration"


class Kind7(Enum):
    validating_webhook_configuration_list = "ValidatingWebhookConfigurationList"


class Kind8(Enum):
    controller_revision = "ControllerRevision"


class Kind9(Enum):
    controller_revision_list = "ControllerRevisionList"


class Kind10(Enum):
    daemon_set = "DaemonSet"


class Kind11(Enum):
    daemon_set_list = "DaemonSetList"


class Kind12(Enum):
    deployment = "Deployment"


class Kind13(Enum):
    deployment_list = "DeploymentList"


class Kind14(Enum):
    replica_set = "ReplicaSet"


class Kind15(Enum):
    replica_set_list = "ReplicaSetList"


class Kind16(Enum):
    stateful_set = "StatefulSet"


class Kind17(Enum):
    stateful_set_list = "StatefulSetList"


class Kind18(Enum):
    controller_revision = "ControllerRevision"


class Kind19(Enum):
    controller_revision_list = "ControllerRevisionList"


class Kind20(Enum):
    deployment = "Deployment"


class Kind21(Enum):
    deployment_list = "DeploymentList"


class Kind22(Enum):
    deployment_rollback = "DeploymentRollback"


class Kind23(Enum):
    scale = "Scale"


class Kind24(Enum):
    stateful_set = "StatefulSet"


class Kind25(Enum):
    stateful_set_list = "StatefulSetList"


class Kind26(Enum):
    controller_revision = "ControllerRevision"


class Kind27(Enum):
    controller_revision_list = "ControllerRevisionList"


class Kind28(Enum):
    daemon_set = "DaemonSet"


class Kind29(Enum):
    daemon_set_list = "DaemonSetList"


class Kind30(Enum):
    deployment = "Deployment"


class Kind31(Enum):
    deployment_list = "DeploymentList"


class Kind32(Enum):
    replica_set = "ReplicaSet"


class Kind33(Enum):
    replica_set_list = "ReplicaSetList"


class Kind34(Enum):
    scale = "Scale"


class Kind35(Enum):
    stateful_set = "StatefulSet"


class Kind36(Enum):
    stateful_set_list = "StatefulSetList"


class Kind37(Enum):
    audit_sink = "AuditSink"


class Kind38(Enum):
    audit_sink_list = "AuditSinkList"


class Kind39(Enum):
    token_request = "TokenRequest"


class Kind40(Enum):
    token_review = "TokenReview"


class Kind41(Enum):
    token_review = "TokenReview"


class Kind42(Enum):
    local_subject_access_review = "LocalSubjectAccessReview"


class Kind43(Enum):
    self_subject_access_review = "SelfSubjectAccessReview"


class Kind44(Enum):
    self_subject_rules_review = "SelfSubjectRulesReview"


class Kind45(Enum):
    subject_access_review = "SubjectAccessReview"


class Kind46(Enum):
    local_subject_access_review = "LocalSubjectAccessReview"


class Kind47(Enum):
    self_subject_access_review = "SelfSubjectAccessReview"


class Kind48(Enum):
    self_subject_rules_review = "SelfSubjectRulesReview"


class Kind49(Enum):
    subject_access_review = "SubjectAccessReview"


class Kind50(Enum):
    horizontal_pod_autoscaler = "HorizontalPodAutoscaler"


class Kind51(Enum):
    horizontal_pod_autoscaler_list = "HorizontalPodAutoscalerList"


class Kind52(Enum):
    scale = "Scale"


class Kind53(Enum):
    horizontal_pod_autoscaler = "HorizontalPodAutoscaler"


class Kind54(Enum):
    horizontal_pod_autoscaler_list = "HorizontalPodAutoscalerList"


class Kind55(Enum):
    horizontal_pod_autoscaler = "HorizontalPodAutoscaler"


class Kind56(Enum):
    horizontal_pod_autoscaler_list = "HorizontalPodAutoscalerList"


class Kind57(Enum):
    job = "Job"


class Kind58(Enum):
    job_list = "JobList"


class Kind59(Enum):
    cron_job = "CronJob"


class Kind60(Enum):
    cron_job_list = "CronJobList"


class Kind61(Enum):
    cron_job = "CronJob"


class Kind62(Enum):
    cron_job_list = "CronJobList"


class Kind63(Enum):
    certificate_signing_request = "CertificateSigningRequest"


class Kind64(Enum):
    certificate_signing_request_list = "CertificateSigningRequestList"


class Kind65(Enum):
    lease = "Lease"


class Kind66(Enum):
    lease_list = "LeaseList"


class Kind67(Enum):
    lease = "Lease"


class Kind68(Enum):
    lease_list = "LeaseList"


class Kind69(Enum):
    binding = "Binding"


class Kind70(Enum):
    component_status = "ComponentStatus"


class Kind71(Enum):
    component_status_list = "ComponentStatusList"


class Kind72(Enum):
    config_map = "ConfigMap"


class Kind73(Enum):
    config_map_list = "ConfigMapList"


class Kind74(Enum):
    endpoints = "Endpoints"


class Kind75(Enum):
    endpoints_list = "EndpointsList"


class Kind76(Enum):
    event = "Event"


class Kind77(Enum):
    event_list = "EventList"


class Kind78(Enum):
    limit_range = "LimitRange"


class Kind79(Enum):
    limit_range_list = "LimitRangeList"


class Kind80(Enum):
    namespace = "Namespace"


class Kind81(Enum):
    namespace_list = "NamespaceList"


class Kind82(Enum):
    node = "Node"


class Kind83(Enum):
    node_list = "NodeList"


class Kind84(Enum):
    persistent_volume = "PersistentVolume"


class Kind85(Enum):
    persistent_volume_claim = "PersistentVolumeClaim"


class Kind86(Enum):
    persistent_volume_claim_list = "PersistentVolumeClaimList"


class Kind87(Enum):
    persistent_volume_list = "PersistentVolumeList"


class Kind88(Enum):
    pod = "Pod"


class Kind89(Enum):
    pod_list = "PodList"


class Kind90(Enum):
    pod_template = "PodTemplate"


class Kind91(Enum):
    pod_template_list = "PodTemplateList"


class Kind92(Enum):
    replication_controller = "ReplicationController"


class Kind93(Enum):
    replication_controller_list = "ReplicationControllerList"


class Kind94(Enum):
    resource_quota = "ResourceQuota"


class Kind95(Enum):
    resource_quota_list = "ResourceQuotaList"


class Kind96(Enum):
    secret = "Secret"


class Kind97(Enum):
    secret_list = "SecretList"


class Kind98(Enum):
    service = "Service"


class Kind99(Enum):
    service_account = "ServiceAccount"


class Kind100(Enum):
    service_account_list = "ServiceAccountList"


class Kind101(Enum):
    service_list = "ServiceList"


class Kind102(Enum):
    endpoint_slice = "EndpointSlice"


class Kind103(Enum):
    endpoint_slice_list = "EndpointSliceList"


class Kind104(Enum):
    event = "Event"


class Kind105(Enum):
    event_list = "EventList"


class Kind106(Enum):
    daemon_set = "DaemonSet"


class Kind107(Enum):
    daemon_set_list = "DaemonSetList"


class Kind108(Enum):
    deployment = "Deployment"


class Kind109(Enum):
    deployment_list = "DeploymentList"


class Kind110(Enum):
    deployment_rollback = "DeploymentRollback"


class Kind111(Enum):
    ingress = "Ingress"


class Kind112(Enum):
    ingress_list = "IngressList"


class Kind113(Enum):
    network_policy = "NetworkPolicy"


class Kind114(Enum):
    network_policy_list = "NetworkPolicyList"


class Kind115(Enum):
    pod_security_policy = "PodSecurityPolicy"


class Kind116(Enum):
    pod_security_policy_list = "PodSecurityPolicyList"


class Kind117(Enum):
    replica_set = "ReplicaSet"


class Kind118(Enum):
    replica_set_list = "ReplicaSetList"


class Kind119(Enum):
    scale = "Scale"


class Kind120(Enum):
    network_policy = "NetworkPolicy"


class Kind121(Enum):
    network_policy_list = "NetworkPolicyList"


class Kind122(Enum):
    ingress = "Ingress"


class Kind123(Enum):
    ingress_list = "IngressList"


class Kind124(Enum):
    runtime_class = "RuntimeClass"


class Kind125(Enum):
    runtime_class_list = "RuntimeClassList"


class Kind126(Enum):
    runtime_class = "RuntimeClass"


class Kind127(Enum):
    runtime_class_list = "RuntimeClassList"


class Kind128(Enum):
    eviction = "Eviction"


class Kind129(Enum):
    pod_disruption_budget = "PodDisruptionBudget"


class Kind130(Enum):
    pod_disruption_budget_list = "PodDisruptionBudgetList"


class Kind131(Enum):
    pod_security_policy = "PodSecurityPolicy"


class Kind132(Enum):
    pod_security_policy_list = "PodSecurityPolicyList"


class Kind133(Enum):
    cluster_role = "ClusterRole"


class Kind134(Enum):
    cluster_role_binding = "ClusterRoleBinding"


class Kind135(Enum):
    cluster_role_binding_list = "ClusterRoleBindingList"


class Kind136(Enum):
    cluster_role_list = "ClusterRoleList"


class Kind137(Enum):
    role = "Role"


class Kind138(Enum):
    role_binding = "RoleBinding"


class Kind139(Enum):
    role_binding_list = "RoleBindingList"


class Kind140(Enum):
    role_list = "RoleList"


class Kind141(Enum):
    cluster_role = "ClusterRole"


class Kind142(Enum):
    cluster_role_binding = "ClusterRoleBinding"


class Kind143(Enum):
    cluster_role_binding_list = "ClusterRoleBindingList"


class Kind144(Enum):
    cluster_role_list = "ClusterRoleList"


class Kind145(Enum):
    role = "Role"


class Kind146(Enum):
    role_binding = "RoleBinding"


class Kind147(Enum):
    role_binding_list = "RoleBindingList"


class Kind148(Enum):
    role_list = "RoleList"


class Kind149(Enum):
    cluster_role = "ClusterRole"


class Kind150(Enum):
    cluster_role_binding = "ClusterRoleBinding"


class Kind151(Enum):
    cluster_role_binding_list = "ClusterRoleBindingList"


class Kind152(Enum):
    cluster_role_list = "ClusterRoleList"


class Kind153(Enum):
    role = "Role"


class Kind154(Enum):
    role_binding = "RoleBinding"


class Kind155(Enum):
    role_binding_list = "RoleBindingList"


class Kind156(Enum):
    role_list = "RoleList"


class Kind157(Enum):
    priority_class = "PriorityClass"


class Kind158(Enum):
    priority_class_list = "PriorityClassList"


class Kind159(Enum):
    priority_class = "PriorityClass"


class Kind160(Enum):
    priority_class_list = "PriorityClassList"


class Kind161(Enum):
    priority_class = "PriorityClass"


class Kind162(Enum):
    priority_class_list = "PriorityClassList"


class Kind163(Enum):
    pod_preset = "PodPreset"


class Kind164(Enum):
    pod_preset_list = "PodPresetList"


class Kind165(Enum):
    storage_class = "StorageClass"


class Kind166(Enum):
    storage_class_list = "StorageClassList"


class Kind167(Enum):
    volume_attachment = "VolumeAttachment"


class Kind168(Enum):
    volume_attachment_list = "VolumeAttachmentList"


class Kind169(Enum):
    volume_attachment = "VolumeAttachment"


class Kind170(Enum):
    volume_attachment_list = "VolumeAttachmentList"


class Kind171(Enum):
    csi_driver = "CSIDriver"


class Kind172(Enum):
    csi_driver_list = "CSIDriverList"


class Kind173(Enum):
    csi_node = "CSINode"


class Kind174(Enum):
    csi_node_list = "CSINodeList"


class Kind175(Enum):
    storage_class = "StorageClass"


class Kind176(Enum):
    storage_class_list = "StorageClassList"


class Kind177(Enum):
    volume_attachment = "VolumeAttachment"


class Kind178(Enum):
    volume_attachment_list = "VolumeAttachmentList"


class Kind179(Enum):
    custom_resource_definition = "CustomResourceDefinition"


class Kind180(Enum):
    custom_resource_definition_list = "CustomResourceDefinitionList"


class Kind181(Enum):
    custom_resource_definition = "CustomResourceDefinition"


class Kind182(Enum):
    custom_resource_definition_list = "CustomResourceDefinitionList"


class Kind183(Enum):
    api_group = "APIGroup"


class Kind184(Enum):
    api_group_list = "APIGroupList"


class Kind185(Enum):
    api_resource_list = "APIResourceList"


class Kind186(Enum):
    api_versions = "APIVersions"


class Kind187(Enum):
    delete_options = "DeleteOptions"


class Kind188(Enum):
    status = "Status"


class Kind189(Enum):
    api_service = "APIService"


class Kind190(Enum):
    api_service_list = "APIServiceList"


class Kind191(Enum):
    api_service = "APIService"


class Kind192(Enum):
    api_service_list = "APIServiceList"
